import requests
from .config import configdb

def guild_data(guild_id:int):
    token = configdb['BOT_TOKEN']
    resp = requests.get(f"https://discord.com/api/v6/guilds/{guild_id}", headers={"Authorization": f"Bot {token}"})
    resp.raise_for_status()
    return resp.json()

def get_emojis(guild_id: int):
    token = configdb['BOT_TOKEN']
    r = requests.get(f"https://discord.com/api/v6/guilds/{guild_id}/emojis", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()
    return r.json()

def get_bans(guild_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.get(f"https://discord.com/api/v8/guilds/{guild_id}/bans", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()
    return r.json()

def create_ban(guild_id:int, user_id:int, delete_message_days:int ,reason:str=None):
    if delete_message_days > 7:
        delete_message_days = 7
    if delete_message_days < 0:
        delete_message_days = 0
    if reason == None:
        reason = "None"
    token = configdb['BOT_TOKEN']
    json = {
        "delete_message_days": delete_message_days,
        "reason": reason
    }
    r = requests.put(f"https://discord.com/api/v8/guilds/{guild_id}/bans/{user_id}", headers={"Authorization": f"Bot {token}"}, json=json)
    r.raise_for_status()

def remove_ban(guild_id:int, user_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.delete(f"https://discord.com/api/v8/guilds/{guild_id}/bans/{user_id}", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()

def get_guild_member(guild_id:int, user_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.get(f"https://discord.com/api/v8/guilds/{guild_id}/members/{user_id}", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()    
    return r.json()

def get_list_members(guild_id:int, member):
    token = configdb['BOT_TOKEN']
    json = {
        "limit": f"{member}"
    }
    r = requests.get(f"https://discord.com/api/v8/guilds/{guild_id}/members", headers={"Authorization": f"Bot {token}"}, params=json)
    r.raise_for_status()
    return r.json()
    
def remove_guild_member(guild_id:int, user_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.delete(f"https://discord.com/api/v8/guilds/{guild_id}/members/{user_id}", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()    

def get_guild_voice_regions(guild_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.get(f"https://discord.com/api/v8/guilds/{guild_id}/regions", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()     
    return r.json()

def get_guild_welcome_screen(guild_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.get(f"https://discord.com/api/v8/guilds/{guild_id}/welcome-screen", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()     
    return r.json()




from os import error
from typing import no_type_check
import requests
from .config import configdb

def get_roles(guild_id: int):
    token = configdb['BOT_TOKEN']
    r = requests.get(f"https://discord.com/api/v6/guilds/{guild_id}/roles", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()
    return r.json()

def add_member_role(guild_id:int, user_id:int, role_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.put(f"https://discord.com/api/v8/guilds/{guild_id}/members/{user_id}/roles/{role_id}", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()

def create_guild_role(guild_id:int, name:str):
    token = configdb['BOT_TOKEN']
    json = {
        "name": name
    }
    r = requests.post(f"https://discord.com/api/v8/guilds/{guild_id}/roles", headers={"Authorization": f"Bot {token}"},json=json)
    r.raise_for_status()

def remove_member_role(guild_id:int, user_id:int, role_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.delete(f"https://discord.com/api/v8/guilds/{guild_id}/members/{user_id}/roles/{role_id}", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()

def delete_guild_role(guild_id:int, role_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.delete(f"https://discord.com/api/v8/guilds/{guild_id}/roles/{role_id}", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()

class Crole:
    def __init__(self, name:str = None, color:int=None):
        self.json = {
        }         
        if name is None:
            self.json["name"] = "Role name"
        else:
            self.json["name"] = name
        if color is None:
            self.json["color"] = None
        else:
            self.json["color"] = color
    def permissions(self, permissions:int= None):
        if permissions is None:
            self.json["permissions"] = 0x01   
        else:
            self.json["permissions"] = permissions
    def saverole(self, guild_id:int = None):
        if guild_id is None:
            return
        else:
            token = configdb['BOT_TOKEN']
            r = requests.post(f"https://discord.com/api/v8/guilds/{guild_id}/roles", headers={"Authorization": f"Bot {token}"},json=self.json)
            r.raise_for_status()

class Erole:
    def __init__(self, name:str = None, color:int=None):
        self.json = {
        }         
        if name is None:
            self.json["name"] = "Role name"
        else:
            self.json["name"] = name
        if color is None:
            self.json["color"] = None
        else:
            self.json["color"] = color
    def permissions(self, permissions:int= None):
        if permissions is None:
            self.json["permissions"] = 0x01   
        else:
            self.json["permissions"] = permissions
    def saverole(self, guild_id:int = None, role_id:int = None):
        token = configdb['BOT_TOKEN']
        r = requests.patch(f"https://discord.com/api/v8/guilds/{guild_id}/roles/{role_id}", headers={"Authorization": f"Bot {token}"},json=self.json)
        r.raise_for_status()


    


from .config import configdb
import requests

def get_channels(guild_id: int):
    token = configdb['BOT_TOKEN']
    r = requests.get(f"https://discord.com/api/v6/guilds/{guild_id}/channels", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()
    return r.json()




import requests
from .config import configdb

def authorization_token(code:str):
  data = {
    'client_id': configdb['CLIENT_ID'],
    'client_secret': configdb['CLIENT_SECRET'],
    'grant_type': 'authorization_code',
    'code': code,
    'redirect_uri': configdb['REDIRECT_URI']
  }
  headers = {
    'Content-Type': 'application/x-www-form-urlencoded'
  }
  r = requests.post("https://discord.com/api/oauth2/token", data=data, headers=headers)
  r.raise_for_status()
  return r.json()['access_token']

def user_data(token:str):
  resp = requests.get(f"https://discord.com/api/oauth2/@me", headers={"Authorization": f"Bearer {token}"})
  resp.raise_for_status()
  return resp.json()['user']

def user_guilds(token:str):
    resp = requests.get("https://discord.com/api/v6/users/@me/guilds", headers={"Authorization": f"Bearer {token}"})
    resp.raise_for_status()
    return resp.json()






import requests
from .config import configdb


def list_active_threads(guild_id:int):
    token = configdb['BOT_TOKEN']
    r = requests.get(f"https://discord.com/api/v8/guilds/{guild_id}/threads/active", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()
    return r.json()    



from setuptools import setup, find_packages

VERSION = '1.2.0'

classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]

setup(name="stepboard",
      version=VERSION,
      author='Stępującybrat#1017',
      author_email='maciejwisniewski.ja@gmail.com',
      license='MIT',
      description='A simple library for making a dashboard in a flask/django.',
      packages=find_packages(),
      install_requires=['']
      )



from sqlalchemy import true
from .config import configdb
import requests

def bot_data():
    token = configdb['BOT_TOKEN']
    resp = requests.get(f"https://discord.com/api/oauth2/applications/@me", headers={"Authorization": f"Bot {token}"})
    resp.raise_for_status()
    return resp.json()

def bot_guilds():
    token = configdb['BOT_TOKEN']
    r= requests.get("https://discord.com/api/v6/users/@me/guilds", headers={"Authorization": f"Bot {token}"})
    r.raise_for_status()
    return r.json()

def common_guilds(user: list, bot:list, permissions = 0x20):
    return [guild for guild in user if guild['id'] in map(lambda i: i['id'], bot) and (guild['permissions'] & permissions) == permissions]

def permissions(user_guilds, guild_id, permissions = 0x20):
    for server in user_guilds:
        if int(server['id']) == int(guild_id):
            if (int(server['permissions_new']) & int(permissions)) == permissions:
                return True
            else:
                return False
